% Single-barrier options, reproduction of Espen Haug's book.

clc; clear;

% Option features.
S = 100;        % Spot price
T = 0.5;        % Maturity in years
r = 0.08;       % Risk free rate
q = 0.04;       % Cost of carry
R = 3;          % Rebate

% Cell for the put/call indicator. 
PutCall = {[repmat('C',18,1); repmat('P',18,1)]};

% Array for the strikes.
X = repmat([90; 100; 110],12,1);

% Array for the barriers.
H = repmat([95; 95; 95; 100; 100; 100; 105; 105; 105],4,1);

% Cell for the barrier types.
BarType = {repmat([repmat('DO',6,1); repmat('UO',3,1); repmat('DI',6,1); repmat('UI',3,1)],2,1)};

% The volatilities
vol = [0.25, 0.30];

% Initialize the price matrix.
Price = zeros(36,2);

% Create the barrier option prices
for i=1:36;
	Price(i,1) = BarrierOp(S,X(i),T,r,q,vol(1),R,H(i),PutCall{1}(i),BarType{1}(i,1:2));
	Price(i,2) = BarrierOp(S,X(i),T,r,q,vol(2),R,H(i),PutCall{1}(i),BarType{1}(i,1:2));
end
Price

